'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.format = exports.getKeyframes = undefined;

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _format = require('./format');

Object.defineProperty(exports, 'format', {
  enumerable: true,
  get: function get() {
    return _interopRequireDefault(_format).default;
  }
});

var _stepper3 = require('./stepper');

var _stepper4 = _interopRequireDefault(_stepper3);

var _cache = require('./cache');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var presets = {
  noWobble: { stiffness: 170, damping: 26 },
  gentle: { stiffness: 120, damping: 14 },
  wobbly: { stiffness: 180, damping: 12 },
  stiff: { stiffness: 210, damping: 20 }
};

var defaults = {
  stiffness: 170,
  damping: 26,
  precision: 3
};

var getKeyframes = exports.getKeyframes = function getKeyframes(startProps, targetProps) {
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  var _Object$assign = Object.assign({}, defaults, options, presets[options.preset] || {}),
      stiffness = _Object$assign.stiffness,
      damping = _Object$assign.damping,
      precision = _Object$assign.precision;

  var steps = {};
  var cache = (0, _cache.initCache)(startProps, targetProps);

  var _loop = function _loop(i) {
    var props = {};
    Object.keys(cache).forEach(function (key) {
      var prop = cache[key];

      var _stepper = (0, _stepper4.default)(0.01, prop.cache.value, prop.cache.velocity, parseFloat(prop.target), stiffness, damping),
          _stepper2 = _slicedToArray(_stepper, 2),
          value = _stepper2[0],
          velocity = _stepper2[1];

      prop.cache = { value: value, velocity: velocity };
      props[key] = +prop.cache.value.toFixed(precision);
    });
    steps[i + '%'] = props;
  };

  for (var i = 1; i < 101; i += 1) {
    _loop(i);
  }
  return steps;
};

exports.default = getKeyframes;